summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendarchange.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsolekalendar/konsolekalendarchange.cpp')
-rw-r--r--konsolekalendar/konsolekalendarchange.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/konsolekalendar/konsolekalendarchange.cpp b/konsolekalendar/konsolekalendarchange.cpp
index fffd38cc..067c05e2 100644
--- a/konsolekalendar/konsolekalendarchange.cpp
+++ b/konsolekalendar/konsolekalendarchange.cpp
@@ -20,8 +20,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
* *
* As a special exception, permission is given to link this program *
* with any edition of Qt, and distribute the resulting executable, *
* without including the source code for Qt in the source distribution. *
* *
******************************************************************************/
/**
@@ -136,11 +136,11 @@ void KonsoleKalendarChange::printSpecs( Event *event )
<< endl;
cout << i18n( " Begin: %1" ).
- arg( event->dtStart().toString( Qt::TextDate ) ).local8Bit()
+ arg( event->dtStart().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " End: %1" ).
- arg( event->dtEnd().toString( Qt::TextDate ) ).local8Bit()
+ arg( event->dtEnd().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " Desc: %1" ).
@@ -163,11 +163,11 @@ void KonsoleKalendarChange::printSpecs()
<< endl;
cout << i18n( " Begin: %1" ).
- arg( m_variables->getStartDateTime().toString( Qt::TextDate ) ).local8Bit()
+ arg( m_variables->getStartDateTime().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " End: %1" ).
- arg( m_variables->getEndDateTime().toString( Qt::TextDate ) ).local8Bit()
+ arg( m_variables->getEndDateTime().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " Desc: %1" ).
@@ -20,8 +20,8 @@
* *
* As a special exception, permission is given to link this program *
- * with any edition of Qt, and distribute the resulting executable, *
- * without including the source code for Qt in the source distribution. *
+ * with any edition of TQt, and distribute the resulting executable, *
+ * without including the source code for TQt in the source distribution. *
* *
******************************************************************************/